import time

# Import the preset TestFixture.
from .Frames_trasnmission_fixture import FixtureFramesTrasnmission, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestFlexrayTransmitter(FixtureFramesTrasnmission):

    # This method will be executed just before
    # the test case method execution.
    def setUp(self):
        logger.info("Setup test case")

    # This method will be executed just after
    # the test case method execution.
    def tearDown(self):
        logger.info("Tear down test case")

    # Create the test case method that holds the main test steps.
    def test_flexray_transmitter(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'B1_FlexRay'
        frame_id = '5.2.64'  # Its type is str.
        payload = [0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8,
                   0x9, 0xa, 0xb, 0xc, 0xd, 0xf, 0x10]

        flx_ch = ChannelFactory().get_flexray_channel(channel_name)

        flx_fr = flx_ch.get_frame(frame_id)

        # Log any useful message.
        logger.info("Transmit a flexray frame")

        # Transmit the flexray frame.
        flex_transmit = flx_fr.transmitter.transmit_frame(payload)

        time.sleep(2)

        # Confirm the correct transmission by verifying
        # the boolean return value of transmit_frame().
        # If there are no issues during transmission,
        # the return value should be true.
        self.assertTrue(flex_transmit, Severity.BLOCKER,
                        "Error when sending a flexray message")
